﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Hotline.Orders;
using Hotline.Repository.SqlSugar.DataPermissions;
using Hotline.Repository.SqlSugar.Extensions;
using Hotline.Share.Enums.Order;
using SqlSugar;
using XF.Domain.Dependency;
using XF.Domain.Exceptions;

namespace Hotline.Repository.SqlSugar.Orders
{
    public class OrderRepository : BaseRepositoryWorkflow<Order>, IOrderRepository, IScopeDependency
    {
        private readonly IDataPermissionFilterBuilder _dataPermissionFilterBuilder;

        public OrderRepository(ISugarUnitOfWork<HotlineDbContext> uow, IDataPermissionFilterBuilder dataPermissionFilterBuilder) : base(uow, dataPermissionFilterBuilder)
        {
            _dataPermissionFilterBuilder = dataPermissionFilterBuilder;
        }

        public async Task<string> AddOrderNavAsync(Order order, CancellationToken cancellationToken)
        {
            if (order.OrderType == EOrderType.MarketSupervisionBy12315)
            {
                if (order.AcceptType == EAcceptType.Complain)
                {
                    if (order.OrderComplain == null)
                        throw UserFriendlyException.SameMessage("非法投诉参数");
                    order.OrderComplain.InitDatePermission(_dataPermissionFilterBuilder.DataPermissionManager);
                    await AddNav(order).Include(d => d.OrderComplain).ExecuteCommandAsync();
                }
                else if (order.AcceptType == EAcceptType.Report)
                {
                    if (order.OrderReport == null)
                        throw UserFriendlyException.SameMessage("非法举报参数");
                    order.OrderReport.InitDatePermission(_dataPermissionFilterBuilder.DataPermissionManager);
                    await AddNav(order).Include(d=>d.OrderReport).ExecuteCommandAsync();
                }
            }
            else
            {
                await AddAsync(order, cancellationToken);
            }
            return order.Id;
        }
    }
}
